Readable

Trait Readable 

pub trait Readable: RegisterSpec { }
Trait implemented by readable registers to enable the read method.

Registers marked with Writable can be also be modify’ed.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl Readable for moondancer_pac::usb0::control::CONTROL_SPEC

read() method returns control::R reader structure

Source

impl Readable for moondancer_pac::usb0_ep_control::control::CONTROL_SPEC

read() method returns control::R reader structure

Source

impl Readable for moondancer_pac::usb0_ep_out::control::CONTROL_SPEC

read() method returns control::R reader structure

Source

impl Readable for moondancer_pac::usb1::control::CONTROL_SPEC

read() method returns control::R reader structure

Source

impl Readable for moondancer_pac::usb1_ep_control::control::CONTROL_SPEC

read() method returns control::R reader structure

Source

impl Readable for moondancer_pac::usb1_ep_out::control::CONTROL_SPEC

read() method returns control::R reader structure

Source

impl Readable for moondancer_pac::usb2::control::CONTROL_SPEC

read() method returns control::R reader structure

Source

impl Readable for moondancer_pac::usb2_ep_control::control::CONTROL_SPEC

read() method returns control::R reader structure

Source

impl Readable for moondancer_pac::usb2_ep_out::control::CONTROL_SPEC

read() method returns control::R reader structure

Source

impl Readable for moondancer_pac::advertiser::control::CONTROL_SPEC

read() method returns control::R reader structure

Source

impl Readable for moondancer_pac::timer0::counter::COUNTER_SPEC

read() method returns counter::R reader structure

Source

impl Readable for moondancer_pac::timer1::counter::COUNTER_SPEC

read() method returns counter::R reader structure

Source

impl Readable for CS_SPEC

read() method returns cs::R reader structure

Source

impl Readable for moondancer_pac::spi0::data::DATA_SPEC

read() method returns data::R reader structure

Source

impl Readable for moondancer_pac::usb0_ep_control::data::DATA_SPEC

read() method returns data::R reader structure

Source

impl Readable for moondancer_pac::usb0_ep_in::data::DATA_SPEC

read() method returns data::R reader structure

Source

impl Readable for moondancer_pac::usb0_ep_out::data::DATA_SPEC

read() method returns data::R reader structure

Source

impl Readable for moondancer_pac::usb1_ep_control::data::DATA_SPEC

read() method returns data::R reader structure

Source

impl Readable for moondancer_pac::usb1_ep_in::data::DATA_SPEC

read() method returns data::R reader structure

Source

impl Readable for moondancer_pac::usb1_ep_out::data::DATA_SPEC

read() method returns data::R reader structure

Source

impl Readable for moondancer_pac::usb2_ep_control::data::DATA_SPEC

read() method returns data::R reader structure

Source

impl Readable for moondancer_pac::usb2_ep_in::data::DATA_SPEC

read() method returns data::R reader structure

Source

impl Readable for moondancer_pac::usb2_ep_out::data::DATA_SPEC

read() method returns data::R reader structure

Source

impl Readable for moondancer_pac::uart0::divisor::DIVISOR_SPEC

read() method returns divisor::R reader structure

Source

impl Readable for moondancer_pac::uart1::divisor::DIVISOR_SPEC

read() method returns divisor::R reader structure

Source

impl Readable for moondancer_pac::timer0::enable::ENABLE_SPEC

read() method returns enable::R reader structure

Source

impl Readable for moondancer_pac::timer1::enable::ENABLE_SPEC

read() method returns enable::R reader structure

Source

impl Readable for moondancer_pac::usb0_ep_out::enable::ENABLE_SPEC

read() method returns enable::R reader structure

Source

impl Readable for moondancer_pac::usb1_ep_out::enable::ENABLE_SPEC

read() method returns enable::R reader structure

Source

impl Readable for moondancer_pac::usb2_ep_out::enable::ENABLE_SPEC

read() method returns enable::R reader structure

Source

impl Readable for moondancer_pac::usb0_ep_in::endpoint::ENDPOINT_SPEC

read() method returns endpoint::R reader structure

Source

impl Readable for moondancer_pac::usb0_ep_out::endpoint::ENDPOINT_SPEC

read() method returns endpoint::R reader structure

Source

impl Readable for moondancer_pac::usb1_ep_in::endpoint::ENDPOINT_SPEC

read() method returns endpoint::R reader structure

Source

impl Readable for moondancer_pac::usb1_ep_out::endpoint::ENDPOINT_SPEC

read() method returns endpoint::R reader structure

Source

impl Readable for moondancer_pac::usb2_ep_in::endpoint::ENDPOINT_SPEC

read() method returns endpoint::R reader structure

Source

impl Readable for moondancer_pac::usb2_ep_out::endpoint::ENDPOINT_SPEC

read() method returns endpoint::R reader structure

Source

impl Readable for moondancer_pac::timer0::ev_enable::EV_ENABLE_SPEC

read() method returns ev_enable::R reader structure

Source

impl Readable for moondancer_pac::timer1::ev_enable::EV_ENABLE_SPEC

read() method returns ev_enable::R reader structure

Source

impl Readable for moondancer_pac::usb0::ev_enable::EV_ENABLE_SPEC

read() method returns ev_enable::R reader structure

Source

impl Readable for moondancer_pac::usb0_ep_control::ev_enable::EV_ENABLE_SPEC

read() method returns ev_enable::R reader structure

Source

impl Readable for moondancer_pac::usb0_ep_in::ev_enable::EV_ENABLE_SPEC

read() method returns ev_enable::R reader structure

Source

impl Readable for moondancer_pac::usb0_ep_out::ev_enable::EV_ENABLE_SPEC

read() method returns ev_enable::R reader structure

Source

impl Readable for moondancer_pac::usb1::ev_enable::EV_ENABLE_SPEC

read() method returns ev_enable::R reader structure

Source

impl Readable for moondancer_pac::usb1_ep_control::ev_enable::EV_ENABLE_SPEC

read() method returns ev_enable::R reader structure

Source

impl Readable for moondancer_pac::usb1_ep_in::ev_enable::EV_ENABLE_SPEC

read() method returns ev_enable::R reader structure

Source

impl Readable for moondancer_pac::usb1_ep_out::ev_enable::EV_ENABLE_SPEC

read() method returns ev_enable::R reader structure

Source

impl Readable for moondancer_pac::usb2::ev_enable::EV_ENABLE_SPEC

read() method returns ev_enable::R reader structure

Source

impl Readable for moondancer_pac::usb2_ep_control::ev_enable::EV_ENABLE_SPEC

read() method returns ev_enable::R reader structure

Source

impl Readable for moondancer_pac::usb2_ep_in::ev_enable::EV_ENABLE_SPEC

read() method returns ev_enable::R reader structure

Source

impl Readable for moondancer_pac::usb2_ep_out::ev_enable::EV_ENABLE_SPEC

read() method returns ev_enable::R reader structure

Source

impl Readable for moondancer_pac::timer0::ev_pending::EV_PENDING_SPEC

read() method returns ev_pending::R reader structure

Source

impl Readable for moondancer_pac::timer1::ev_pending::EV_PENDING_SPEC

read() method returns ev_pending::R reader structure

Source

impl Readable for moondancer_pac::usb0::ev_pending::EV_PENDING_SPEC

read() method returns ev_pending::R reader structure

Source

impl Readable for moondancer_pac::usb0_ep_control::ev_pending::EV_PENDING_SPEC

read() method returns ev_pending::R reader structure

Source

impl Readable for moondancer_pac::usb0_ep_in::ev_pending::EV_PENDING_SPEC

read() method returns ev_pending::R reader structure

Source

impl Readable for moondancer_pac::usb0_ep_out::ev_pending::EV_PENDING_SPEC

read() method returns ev_pending::R reader structure

Source

impl Readable for moondancer_pac::usb1::ev_pending::EV_PENDING_SPEC

read() method returns ev_pending::R reader structure

Source

impl Readable for moondancer_pac::usb1_ep_control::ev_pending::EV_PENDING_SPEC

read() method returns ev_pending::R reader structure

Source

impl Readable for moondancer_pac::usb1_ep_in::ev_pending::EV_PENDING_SPEC

read() method returns ev_pending::R reader structure

Source

impl Readable for moondancer_pac::usb1_ep_out::ev_pending::EV_PENDING_SPEC

read() method returns ev_pending::R reader structure

Source

impl Readable for moondancer_pac::usb2::ev_pending::EV_PENDING_SPEC

read() method returns ev_pending::R reader structure

Source

impl Readable for moondancer_pac::usb2_ep_control::ev_pending::EV_PENDING_SPEC

read() method returns ev_pending::R reader structure

Source

impl Readable for moondancer_pac::usb2_ep_in::ev_pending::EV_PENDING_SPEC

read() method returns ev_pending::R reader structure

Source

impl Readable for moondancer_pac::usb2_ep_out::ev_pending::EV_PENDING_SPEC

read() method returns ev_pending::R reader structure

Source

impl Readable for moondancer_pac::leds::input::INPUT_SPEC

read() method returns input::R reader structure

Source

impl Readable for moondancer_pac::gpio0::input::INPUT_SPEC

read() method returns input::R reader structure

Source

impl Readable for moondancer_pac::gpio1::input::INPUT_SPEC

read() method returns input::R reader structure

Source

impl Readable for moondancer_pac::user0::input::INPUT_SPEC

read() method returns input::R reader structure

Source

impl Readable for moondancer_pac::leds::mode::MODE_SPEC

read() method returns mode::R reader structure

Source

impl Readable for moondancer_pac::gpio0::mode::MODE_SPEC

read() method returns mode::R reader structure

Source

impl Readable for moondancer_pac::gpio1::mode::MODE_SPEC

read() method returns mode::R reader structure

Source

impl Readable for moondancer_pac::timer0::mode::MODE_SPEC

read() method returns mode::R reader structure

Source

impl Readable for moondancer_pac::timer1::mode::MODE_SPEC

read() method returns mode::R reader structure

Source

impl Readable for moondancer_pac::user0::mode::MODE_SPEC

read() method returns mode::R reader structure

Source

impl Readable for moondancer_pac::leds::output::OUTPUT_SPEC

read() method returns output::R reader structure

Source

impl Readable for moondancer_pac::gpio0::output::OUTPUT_SPEC

read() method returns output::R reader structure

Source

impl Readable for moondancer_pac::gpio1::output::OUTPUT_SPEC

read() method returns output::R reader structure

Source

impl Readable for moondancer_pac::user0::output::OUTPUT_SPEC

read() method returns output::R reader structure

Source

impl Readable for PHY_SPEC

read() method returns phy::R reader structure

Source

impl Readable for moondancer_pac::usb0_ep_in::pid::PID_SPEC

read() method returns pid::R reader structure

Source

impl Readable for moondancer_pac::usb0_ep_out::pid::PID_SPEC

read() method returns pid::R reader structure

Source

impl Readable for moondancer_pac::usb1_ep_in::pid::PID_SPEC

read() method returns pid::R reader structure

Source

impl Readable for moondancer_pac::usb1_ep_out::pid::PID_SPEC

read() method returns pid::R reader structure

Source

impl Readable for moondancer_pac::usb2_ep_in::pid::PID_SPEC

read() method returns pid::R reader structure

Source

impl Readable for moondancer_pac::usb2_ep_out::pid::PID_SPEC

read() method returns pid::R reader structure

Source

impl Readable for moondancer_pac::usb0_ep_out::prime::PRIME_SPEC

read() method returns prime::R reader structure

Source

impl Readable for moondancer_pac::usb1_ep_out::prime::PRIME_SPEC

read() method returns prime::R reader structure

Source

impl Readable for moondancer_pac::usb2_ep_out::prime::PRIME_SPEC

read() method returns prime::R reader structure

Source

impl Readable for moondancer_pac::timer0::reload::RELOAD_SPEC

read() method returns reload::R reader structure

Source

impl Readable for moondancer_pac::timer1::reload::RELOAD_SPEC

read() method returns reload::R reader structure

Source

impl Readable for moondancer_pac::usb0_ep_control::reset::RESET_SPEC

read() method returns reset::R reader structure

Source

impl Readable for moondancer_pac::usb0_ep_in::reset::RESET_SPEC

read() method returns reset::R reader structure

Source

impl Readable for moondancer_pac::usb0_ep_out::reset::RESET_SPEC

read() method returns reset::R reader structure

Source

impl Readable for moondancer_pac::usb1_ep_control::reset::RESET_SPEC

read() method returns reset::R reader structure

Source

impl Readable for moondancer_pac::usb1_ep_in::reset::RESET_SPEC

read() method returns reset::R reader structure

Source

impl Readable for moondancer_pac::usb1_ep_out::reset::RESET_SPEC

read() method returns reset::R reader structure

Source

impl Readable for moondancer_pac::usb2_ep_control::reset::RESET_SPEC

read() method returns reset::R reader structure

Source

impl Readable for moondancer_pac::usb2_ep_in::reset::RESET_SPEC

read() method returns reset::R reader structure

Source

impl Readable for moondancer_pac::usb2_ep_out::reset::RESET_SPEC

read() method returns reset::R reader structure

Source

impl Readable for moondancer_pac::uart0::rx_avail::RX_AVAIL_SPEC

read() method returns rx_avail::R reader structure

Source

impl Readable for moondancer_pac::uart1::rx_avail::RX_AVAIL_SPEC

read() method returns rx_avail::R reader structure

Source

impl Readable for moondancer_pac::uart0::rx_data::RX_DATA_SPEC

read() method returns rx_data::R reader structure

Source

impl Readable for moondancer_pac::uart1::rx_data::RX_DATA_SPEC

read() method returns rx_data::R reader structure

Source

impl Readable for moondancer_pac::leds::set_clr::SET_CLR_SPEC

read() method returns set_clr::R reader structure

Source

impl Readable for moondancer_pac::gpio0::set_clr::SET_CLR_SPEC

read() method returns set_clr::R reader structure

Source

impl Readable for moondancer_pac::gpio1::set_clr::SET_CLR_SPEC

read() method returns set_clr::R reader structure

Source

impl Readable for moondancer_pac::user0::set_clr::SET_CLR_SPEC

read() method returns set_clr::R reader structure

Source

impl Readable for moondancer_pac::usb0_ep_in::stall::STALL_SPEC

read() method returns stall::R reader structure

Source

impl Readable for moondancer_pac::usb0_ep_out::stall::STALL_SPEC

read() method returns stall::R reader structure

Source

impl Readable for moondancer_pac::usb1_ep_in::stall::STALL_SPEC

read() method returns stall::R reader structure

Source

impl Readable for moondancer_pac::usb1_ep_out::stall::STALL_SPEC

read() method returns stall::R reader structure

Source

impl Readable for moondancer_pac::usb2_ep_in::stall::STALL_SPEC

read() method returns stall::R reader structure

Source

impl Readable for moondancer_pac::usb2_ep_out::stall::STALL_SPEC

read() method returns stall::R reader structure

Source

impl Readable for moondancer_pac::spi0::status::STATUS_SPEC

read() method returns status::R reader structure

Source

impl Readable for moondancer_pac::usb0::status::STATUS_SPEC

read() method returns status::R reader structure

Source

impl Readable for moondancer_pac::usb0_ep_control::status::STATUS_SPEC

read() method returns status::R reader structure

Source

impl Readable for moondancer_pac::usb0_ep_in::status::STATUS_SPEC

read() method returns status::R reader structure

Source

impl Readable for moondancer_pac::usb0_ep_out::status::STATUS_SPEC

read() method returns status::R reader structure

Source

impl Readable for moondancer_pac::usb1::status::STATUS_SPEC

read() method returns status::R reader structure

Source

impl Readable for moondancer_pac::usb1_ep_control::status::STATUS_SPEC

read() method returns status::R reader structure

Source

impl Readable for moondancer_pac::usb1_ep_in::status::STATUS_SPEC

read() method returns status::R reader structure

Source

impl Readable for moondancer_pac::usb1_ep_out::status::STATUS_SPEC

read() method returns status::R reader structure

Source

impl Readable for moondancer_pac::usb2::status::STATUS_SPEC

read() method returns status::R reader structure

Source

impl Readable for moondancer_pac::usb2_ep_control::status::STATUS_SPEC

read() method returns status::R reader structure

Source

impl Readable for moondancer_pac::usb2_ep_in::status::STATUS_SPEC

read() method returns status::R reader structure

Source

impl Readable for moondancer_pac::usb2_ep_out::status::STATUS_SPEC

read() method returns status::R reader structure

Source

impl Readable for moondancer_pac::uart0::tx_data::TX_DATA_SPEC

read() method returns tx_data::R reader structure

Source

impl Readable for moondancer_pac::uart1::tx_data::TX_DATA_SPEC

read() method returns tx_data::R reader structure

Source

impl Readable for moondancer_pac::uart0::tx_ready::TX_READY_SPEC

read() method returns tx_ready::R reader structure

Source

impl Readable for moondancer_pac::uart1::tx_ready::TX_READY_SPEC

read() method returns tx_ready::R reader structure

Source

impl Readable for VERSION_SPEC

read() method returns version::R reader structure